@@ -3,6 +3,7 @@
    Subroutines providing general support for objects. */
 
 /*
+ * Copyright (c) 2009,2013,2014 by Internet Systems Consortium, Inc. ("ISC")
  * Copyright (c) 2004,2007 by Internet Systems Consortium, Inc. ("ISC")
  * Copyright (c) 1999-2003 by Internet Software Consortium
  *
@@ -22,14 +23,8 @@
  *   950 Charter Street
  *   Redwood City, CA 94063
  *   <info@isc.org>
- *   http://www.isc.org/
+ *   https://www.isc.org/
  *
- * This software has been written for Internet Systems Consortium
- * by Ted Lemon in cooperation with Vixie Enterprises and Nominum, Inc.
- * To learn more about Internet Systems Consortium, see
- * ``http://www.isc.org/''.  To learn more about Vixie Enterprises,
- * see ``http://www.vix.com''.   To learn more about Nominum, Inc., see
- * ``http://www.nominum.com''.
  */
 
 #include "dhcpd.h"
@@ -47,6 +42,11 @@ dhcpctl_status dhcpctl_initialize ()
 {
 	isc_result_t status;
 
+	/* Set up the isc and dns library managers */
+	status = dhcp_context_create();
+	if (status != ISC_R_SUCCESS)
+		return status;
+
 	status = omapi_init();
 	if (status != ISC_R_SUCCESS)
 		return status;
@@ -107,7 +107,7 @@ dhcpctl_status dhcpctl_connect (dhcpctl_handle *connection,
 					 (unsigned)port, authinfo);
 	if (status == ISC_R_SUCCESS)
 		return status;
-	if (status != ISC_R_INCOMPLETE) {
+	if (status != DHCP_R_INCOMPLETE) {
 		omapi_object_dereference (connection, MDL);
 		return status;
 	}
@@ -242,6 +242,7 @@ dhcpctl_status dhcpctl_get_boolean (int *result,
 	}
 	memcpy (&rv, data -> value, sizeof rv);
 	*result = ntohl (rv);
+	omapi_data_string_dereference (&data, MDL);
 	return ISC_R_SUCCESS;
 }
 
@@ -439,7 +440,7 @@ dhcpctl_status dhcpctl_object_update (dhcpctl_handle connection,
 	dhcpctl_remote_object_t *ro;
 
 	if (h -> type != dhcpctl_remote_type)
-		return ISC_R_INVALIDARG;
+		return DHCP_R_INVALIDARG;
 	ro = (dhcpctl_remote_object_t *)h;
 
 	status = omapi_message_new (&message, MDL);
@@ -488,7 +489,7 @@ dhcpctl_status dhcpctl_object_refresh (dhcpctl_handle connection,
 	dhcpctl_remote_object_t *ro;
 
 	if (h -> type != dhcpctl_remote_type)
-		return ISC_R_INVALIDARG;
+		return DHCP_R_INVALIDARG;
 	ro = (dhcpctl_remote_object_t *)h;
 
 	status = omapi_message_new (&message, MDL);
@@ -541,7 +542,7 @@ dhcpctl_status dhcpctl_object_remove (dhcpctl_handle connection,
 	dhcpctl_remote_object_t *ro;
 
 	if (h -> type != dhcpctl_remote_type)
-		return ISC_R_INVALIDARG;
+		return DHCP_R_INVALIDARG;
 	ro = (dhcpctl_remote_object_t *)h;
 
 	status = omapi_message_new (&message, MDL);
